# Copyright (C) 2023-2023 LabWare
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the 'Software'), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

#
# LibGBSs-specific support code
#
import gdb

#
# Register couple of events not (yet) supported by the
# GDB/MI.
#
if hasattr(gdb, 'notify_mi'):
    def __on_register_change(event):
        # Sadly, there's no way to get from gdb.Frame to gdb.Thread (and to gdb.Inferior)
        gdb.notify_mi('-register-changed', { 'frame' : event.frame.level() , 'regnum' : event.regnum })

    gdb.events.register_changed.connect(__on_register_change)
else:
    gdb.write("This GDB has no support for custom GDB/MI notifications\n" +
              "This means LibGDBs cannot track register changes made \n"  +
              "from GDB CLI. You may want to upgrade your GDB.")

loaded = True
